@@ -20,6 +20,7 @@ import (
 	"fmt"
 	"path"
 	"path/filepath"
+	"sort"
 	"strings"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/dbfactory"
@@ -128,7 +129,7 @@ func NewParseOpts(ctx context.Context, apr *argparser.ArgParseResults, rsr RepoS
 
 	remoteName := "origin"
 
-	args := apr.Args()
+	args := apr.Args
 	if len(args) == 1 {
 		if _, ok := remotes[args[0]]; ok {
 			remoteName = args[0]
@@ -460,3 +461,36 @@ func getAbsFileRemoteUrl(urlStr string, fs filesys2.Filesys) (string, error) {
 	}
 	return dbfactory.FileScheme + "://" + urlStr, nil
 }
+
+// GetDefaultBranch returns the default branch from among the branches given, returning
+// the configs default config branch first, then init branch main, then the old init branch master,
+// and finally the first lexicographical branch if none of the others are found
+func GetDefaultBranch(dEnv *DoltEnv, branches []ref.DoltRef) string {
+	if len(branches) == 0 {
+		return DefaultInitBranch
+	}
+
+	sort.Slice(branches, func(i, j int) bool {
+		return branches[i].GetPath() < branches[j].GetPath()
+	})
+
+	branchMap := make(map[string]ref.DoltRef)
+	for _, b := range branches {
+		branchMap[b.GetPath()] = b
+	}
+
+	if _, ok := branchMap[DefaultInitBranch]; ok {
+		return DefaultInitBranch
+	}
+	if _, ok := branchMap["master"]; ok {
+		return "master"
+	}
+
+	// todo: do we care about this during clone?
+	defaultOrMain := GetDefaultInitBranch(dEnv.Config)
+	if _, ok := branchMap[defaultOrMain]; ok {
+		return defaultOrMain
+	}
+
+	return branches[0].GetPath()
+}
