@@ -35,7 +35,7 @@ type MergeFunc struct {
 }
 
 // NewMergeFunc creates a new MergeFunc expression.
-func NewMergeFunc(ctx *sql.Context, args ...sql.Expression) (sql.Expression, error) {
+func NewMergeFunc(args ...sql.Expression) (sql.Expression, error) {
 	return &MergeFunc{children: args}, nil
 }
 
@@ -250,8 +250,8 @@ func (cf *MergeFunc) Children() []sql.Expression {
 }
 
 // WithChildren implements the Expression interface.
-func (cf *MergeFunc) WithChildren(ctx *sql.Context, children ...sql.Expression) (sql.Expression, error) {
-	return NewMergeFunc(ctx, children...)
+func (cf *MergeFunc) WithChildren(children ...sql.Expression) (sql.Expression, error) {
+	return NewMergeFunc(children...)
 }
 
 // Type implements the Expression interface.
